import javax.swing.JComponent;
import java.awt.*;
import java.awt.geom.*;
/**
 * A simple graphics component, displaying a shape that moves at every
 * redisplay, and then triggers a redisplay so the shape appears to
 * move continuously.
 * Changes since version 10: the information about the shape is now stored
 * in a separate Box class rather than in instance variables of MyComponent.
 * The behavior should be exactly the same, but this approach is much more
 * flexible (as we'll see in subsequent versions).
 * 
 * @author Stephen Bloch
 * @version 11, Sept 13 2006
 */
public class MyComponent extends JComponent
{
    // instance variables
    /** @since version 11 */
    private Box theBox;
    /**
     * Constructor for objects of class MyComponent
     */
    public MyComponent()
    {
        // initialize instance variables
        this.theBox = new Box(75, 58);
    }

    /**
     * Display a box.
     * 
     * @param  g    a Graphics context into which we are to draw
     */
    public void paintComponent (Graphics g) {
        final int BOX_DX = 2, BOX_DY = 3;
        
        Graphics2D g2 = (Graphics2D)g;
        
        this.theBox.show (g2);
        
        // update the location
        this.theBox.move (BOX_DX, BOX_DY);
        
        // force another redisplay soon
        this.repaint (this.getVisibleRect());
    }
}
